summaryrefslogtreecommitdiff
path: root/protocols/Discord/src/proto.h
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2017-09-27 19:29:19 +0300
committerGeorge Hazan <ghazan@miranda.im>2017-09-27 19:29:19 +0300
commit0779b188d44b7795f4482c7066a064a38d7c130a (patch)
tree59c150d9d06b715f694b3373af6090c47ae2b32e /protocols/Discord/src/proto.h
parent70df70d9bf061fd42523357bc8a34bf4323da964 (diff)
Discord: option to hide guild chats on startup
Diffstat (limited to 'protocols/Discord/src/proto.h')
-rw-r--r--protocols/Discord/src/proto.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/protocols/Discord/src/proto.h b/protocols/Discord/src/proto.h
index b2d18e4350..56c04ef157 100644
--- a/protocols/Discord/src/proto.h
+++ b/protocols/Discord/src/proto.h
@@ -235,7 +235,8 @@ class CDiscordProto : public PROTO<CDiscordProto>
// options
CMOption<wchar_t*> m_wszEmail; // my own email
- CMOption<wchar_t*> m_wszDefaultGroup; // clist group to store contacts
+ CMOption<wchar_t*> m_wszDefaultGroup; // clist group to store contacts
+ CMOption<BYTE> m_bHideGroupchats; // hide guild chats on startup
//////////////////////////////////////////////////////////////////////////////////////
// common data